<?php
/**
 * realm functions and definitions
 *
 * @package realm
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */


	
if ( ! isset( $content_width ) ) {
	$content_width = 640; /* pixels */
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function realm_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on realm, use a find and replace
	 * to change 'realm' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'realm', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

	add_editor_style();

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'realm' ),
	) );

	// Enable support for Post Formats.
	add_theme_support( 'post-formats', array( 'aside', 'image', 'video', 'quote', 'link' ) );

	// Setup the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'realm_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
	) ) );

	// Enable support for HTML5 markup.
	add_theme_support( 'html5', array(
		'comment-list',
		'search-form',
		'comment-form',
		'gallery',
	) );
}

add_action( 'after_setup_theme', 'realm_setup' );

/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function realm_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'realm' ),
		'id'            => 'sidebar-1',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h1 class="widget-title">',
		'after_title'   => '</h1>',
	) );
}
add_action( 'widgets_init', 'realm_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function realm_scripts() {

	wp_enqueue_style( 'realm-css1', get_template_directory_uri().'/css/uikit.gradient.min.css');
	
	wp_enqueue_style( 'realm-css2', get_template_directory_uri().'/css/uikit.almost-flat.css');
	
	wp_enqueue_style( 'realm-css3', get_template_directory_uri().'/css/uikit.css');

	wp_enqueue_style( 'style', get_stylesheet_uri() );

	wp_enqueue_script('jquery');

	wp_enqueue_script( 'jquery-masonry', array('jquery'),'', false );

	wp_enqueue_script( 'realm-navigation', get_template_directory_uri() . '/js/navigation.js', array(), true );

	wp_enqueue_script( 'realm-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), true );

	wp_enqueue_script( 'realm-js', get_template_directory_uri() . '/js/uikit.js', array(), true );

	wp_enqueue_script( 'main-js', get_template_directory_uri() . '/js/main.js', array(), true );

	wp_enqueue_style('googlefont-first', '//fonts.googleapis.com/css?family=Open+Sans');

	wp_enqueue_style('googlefont-second', '//fonts.googleapis.com/css?family=Oxygen');

	wp_enqueue_style('googlefont-third', '//fonts.googleapis.com/css?family=Trochut:400,400italic,700');

	wp_enqueue_style('googlefont-fourth', '//fonts.googleapis.com/css?family=Crushed');

	wp_enqueue_style('googlefont-fifth', '//fonts.googleapis.com/css?family=Old+Standard+TT:400');

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'realm_scripts' );

function realm_style() {
	if(is_user_logged_in()){
		?>
			<style>
				.uk-offcanvas-bar{
					padding-top: 32px;
				}
			</style>
		<?php
	}
}

add_action( 'wp_head', 'realm_style' );


function realm_posts_nav() {
	if(is_single()):
	?>
		<ul class="uk-pagination">
			<?php previous_post_link( '<li class="uk-pagination-previous">%link</li>', '<span class="meta-nav">' . _x( '&larr;', 'Previous post link', 'realm') . '</span> %title' ); ?>
			<?php next_post_link( '<li class="uk-pagination-next">%link</li>', '%title <span class="meta-nav">' . _x( '&rarr;', 'Next post link', 'realm') . '</span>' ); ?>
		</ul>
	<?php	
	else:
		global $wp_query;
		$big = 999999999;
		echo paginate_links( array(
			'base' => str_replace( $big, '%#%', esc_url( get_pagenum_link( $big ) ) ),
			'format' => '?paged=%#%',
			'current' => max( 1, get_query_var('paged') ),
			'total' => $wp_query->max_num_pages,
			'prev_next'    => True,
			'prev_text'    => __('&laquo;','realm'),
			'next_text'    => __('&raquo;','realm'),
		) );
	endif;	
}

function realm_customize_register_option($wp_customize){

    $wp_customize->add_section( 'realm_logo_section' , array(
	    'title'       => __( 'Logo', 'realm' ),
	    'priority'    => 30,
	    'description' => 'Upload a logo to replace the default site name and description in the header',
	));
  		
  	$wp_customize->add_setting( 'realm_logo',array(
  		'sanitize_callback' => 'esc_url_raw'
  	));

  	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'realm_logo', array(
	    'label'    => __( 'Logo', 'realm' ),
	    'section'  => 'realm_logo_section',
	    'settings' => 'realm_logo',
	)));
    
    $wp_customize->add_section('realm_post_scheme', array(
        'title'    => __('Post Scheme', 'realm'),
        'priority' => 120,
    ));
 
     $wp_customize->add_setting('realm_theme_options[header_select]', array(
        'default'        => 'value2',
        'capability'     => 'edit_theme_options',
        'type'           => 'option',
        'sanitize_callback' => 'esc_url_raw'
 
    ));
    $wp_customize->add_control( 'example_select_box', array(
        'settings' => 'realm_theme_options[header_select]',
        'label'   => 'Select Something:',
        'section' => 'realm_post_scheme',
        'type'    => 'select',
        'choices'    => array(
            'value2' => 'Choice 2',
            'value3' => 'Choice 3',
        ),
    )); 
}
 
add_action('customize_register', 'realm_customize_register_option');



/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';

class realm_navwalker extends Walker_Nav_Menu {



		function start_lvl( &$output, $depth=0,$args=array()) {



			$indent = str_repeat( "\t", $depth );



                            
			$output	   .= "\n$indent<div style=\"overflow:hidden;height:auto;position:relative;\"><ul class=\"uk-nav-sub\">\n";		



		}



		function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {



			global $wp_query;



			$indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';



			if (strcasecmp($item->title, 'divider') == 0) {



				$output .= $indent . '<li class="divider">';



			} else if (strcasecmp($item->title, 'divider-vertical') == 0) {



				$output .= $indent . '<li class="divider-vertical">';



			} else if (strcasecmp($item->title, 'nav-header') == 0) {



				$output .= $indent . '<li class="nav-header">' . esc_attr( $item->attr_title );



			} else {





				$class_names = $value = '';



				$classes = empty( $item->classes ) ? array() : (array) $item->classes;



				$classes[] = ($item->current) ? 'active' : '';



				$classes[] = 'menu-item-' . $item->ID;



				$class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item, $args ) );







				if ($args->has_children && $depth > 0) {



					$class_names .= ' uk-parent';



				} else if($args->has_children && $depth === 0) {



					$class_names .= ' uk-parent';



				}



				$class_names = $class_names ? ' class="' . esc_attr( $class_names ) . '"' : '';



				$id = apply_filters( 'nav_menu_item_id', 'menu-item-'. $item->ID, $item, $args );



				$id = $id ? ' id="' . esc_attr( $id ) . '"' : '';



				$output .= $indent . '<li' . $id . $value . $class_names .'>';



	            if($args->has_children && $depth === 0 && $class_names='dropdown') 



				{

					$attributes = ! empty( $item->target )     ? ' target="' . esc_attr( $item->target     ) .'"' : '';



					$attributes .= ! empty( $item->xfn )        ? ' rel="'    . esc_attr( $item->xfn        ) .'"' : '';



					$attributes .= ! empty( $item->url )        ? ' href="'   . esc_attr( $item->url        ) .'"' : '';



					$attributes .= ($args->has_children) 	    ? ' data-toggle="dropdown" data-target="#" class="dropdown-toggle"' : '';



					$item_output = $args->before;

				}

				else

				{

					$attributes = ! empty( $item->target )     ? ' target="' . esc_attr( $item->target     ) .'"' : '';



					$attributes .= ! empty( $item->xfn )        ? ' rel="'    . esc_attr( $item->xfn        ) .'"' : '';



					$attributes .= ! empty( $item->url )        ? ' href="'   . esc_attr( $item->url        ) .'"' : '';



					$attributes .= ($args->has_children) 	    ? ' data-toggle="dropdown" data-target="#" class="dropdown-toggle"' : '';



					$item_output = $args->before;

	            }



				if(! empty( $item->attr_title )){



					$item_output .= '<a'. $attributes .'><i class="' . esc_attr( $item->attr_title ) . '"></i>&nbsp;';



				} else {



					$item_output .= '<a'. $attributes .'>';



				}



				$item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;



				$item_output .= ($args->has_children && $depth == 0) ? ' <span class="caret"></span></a>' : '</a>';



				$item_output .= $args->after;



				$output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );



			}



		}



		function display_element( $element, &$children_elements, $max_depth, $depth, $args, &$output ) {



	        if ( !$element ) {



	            return;



	        }



	        $id_field = $this->db_fields['id'];



	        if ( is_object( $args[0] ) ) {



	           $args[0]->has_children = ! empty( $children_elements[$element->$id_field] );



	        }

	        parent::display_element($element, $children_elements, $max_depth, $depth, $args, $output);

	    }

}